@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -562,6 +562,11 @@ gog_themes_init	(void)
 	gog_theme_add_element (theme, style,
 		NULL, "GogRegEqn", NULL);
 
+	/* series lines */
+	style = gog_style_new ();
+	gog_theme_add_element (theme, style,
+		map_area_series_solid_default, "GogSeriesLines", NULL);
+
 /* Guppi */
 	theme = gog_theme_new (N_("Guppi"));
 	gog_theme_register (theme, FALSE);
@@ -663,10 +668,13 @@ gog_themes_init	(void)
 	style->outline.dash_type = GO_LINE_SOLID;
 	style->outline.width = 0; /* hairline */
 	style->outline.color = RGBA_BLACK;
-	style->fill.type = GOG_FILL_STYLE_PATTERN;
-	go_pattern_set_solid (&style->fill.pattern, 0);
 	gog_theme_add_element (theme, style,
 		NULL, "GogRegEqn", NULL);
+
+	/* series lines */
+	style = gog_style_new ();
+	gog_theme_add_element (theme, style,
+		NULL, "GogSeriesLines", NULL);
 }
 
 void
